@@ -10,11 +10,11 @@ struct block {
 };
 
 struct template {
-        char *name;
-        /* blocks: header, item, footer */
+	char *name;
+	/* blocks: header, item, footer */
 	struct block blocks[BlockLast];
-        /* output FILE * (set at runtime) */
-        FILE *fp;
+	/* output FILE * (set at runtime) */
+	FILE *fp;
 };
 
 static struct template templates[] = {
@@ -53,5 +53,12 @@ static struct template templates[] = {
 			{ .name = "urllist.txt/item.txt" },
 			{ .name = "urllist.txt/footer.txt" }
 		}
+	},
+	{
+		.name = "twtxt.txt", .blocks = {
+			{ .name = "twtxt.txt/header.txt" },
+			{ .name = "twtxt.txt/item.txt" },
+			{ .name = "twtxt.txt/footer.txt" }
+		}
 	}
 };
