@@ -4,8 +4,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#ifdef USE_PLEDGE
+
+/* OpenBSD pledge(2) */
+#ifdef __OpenBSD__
 #include <unistd.h>
+#else
+#define pledge(p1,p2) 0
 #endif
 
 /* This is the blocksize of my disk, use atleast an equal or higher value and
@@ -25,10 +29,6 @@ char *argv0;
 
 static struct variable *global;
 
-#ifndef USE_PLEDGE
-#define pledge(p1,p2) 0
-#endif
-
 /* Escape characters below as HTML 2.0 / XML 1.0. */
 void
 xmlencode(const char *s, FILE *fp)
@@ -218,40 +218,53 @@ freevars(struct variable *vars)
 }
 
 struct variable *
-parsevars(const char *s)
+parsevars(const char *file, const char *s)
 {
 	struct variable *vars = NULL, *v;
 	const char *keystart, *keyend, *valuestart, *valueend;
+	size_t line = 0;
 
 	for (; *s; ) {
-		/* comment start with #, skip to newline */
-		if (*s == '#') {
-			s = &s[strcspn(s + 1, "\n")];
-			continue;
-		}
 		if (*s == '\r' || *s == '\n') {
+			line += (*s == '\n');
 			s++;
 			continue;
 		}
 
+		/* comment start with #, skip to newline */
+		if (*s == '#') {
+			s++;
+			s = &s[strcspn(s, "\n")];
+			continue;
+		}
+
+		/* trim whitespace before key */
+		s = &s[strspn(s, " \t")];
+
 		keystart = s;
 		s = &s[strcspn(s, "=\r\n")];
 		if (*s != '=') {
-			s++;
-			continue;
+			fprintf(stderr, "%s:%zu: error: no variable\n",
+			        file, line + 1);
+			exit(1);
 		}
-		for (keyend = s; keyend > keystart &&
+
+		/* trim whitespace at end of key: but whitespace in names are
+		   allowed */
+		for (keyend = s++; keyend > keystart &&
 		                 (keyend[-1] == ' ' || keyend[-1] == '\t');
 		     keyend--)
 			;
 		/* no variable name: skip */
-		if (keystart == keyend)
-			continue;
+		if (keystart == keyend) {
+			fprintf(stderr, "%s:%zu: error: invalid variable\n",
+			        file, line + 1);
+			exit(1);
+		}
 
-		for (s++; *s && (*s == ' ' || *s == '\t'); s++)
-			;
 		valuestart = s;
-		valueend = &s[strcspn(s, "\r\n")];
+		s = &s[strcspn(s, "\r\n")];
+		valueend = s;
 
 		v = ecalloc(1, sizeof(*v));
 		v->key = ecalloc(1, keyend - keystart + 1);
@@ -271,14 +284,14 @@ readconfig(const char *file)
 	char *data;
 
 	data = readfile(file);
-	c = parsevars(data);
+	c = parsevars(file, data);
 	free(data);
 
 	return c;
 }
 
 void
-writepage(FILE *fp, const char *filename, struct variable *c, char *s)
+writepage(FILE *fp, const char *file, struct variable *c, char *s)
 {
 	FILE *fpin;
 	struct variable *v;
@@ -289,9 +302,9 @@ writepage(FILE *fp, const char *filename, struct variable *c, char *s)
 	for (; *s; s++) {
 		op = *s;
 		switch (*s) {
-		case '%': /* insert contents of filename set in variable */
 		case '#': /* insert value non-escaped */
 		case '$': /* insert value escaped */
+		case '%': /* insert contents of filename set in variable */
 			if (*(s + 1) == '{') {
 				s += 2;
 				break;
@@ -306,13 +319,13 @@ writepage(FILE *fp, const char *filename, struct variable *c, char *s)
 		}
 
 		/* variable case */
-		for (; *s && isspace(*s); s++)
+		for (; *s && isspace((unsigned char)*s); s++)
 			;
 		key = s;
 		for (keylen = 0; *s && *s != '}'; s++)
 			keylen++;
 		/* trim right whitespace */
-		for (; keylen && isspace(key[keylen - 1]); )
+		for (; keylen && isspace((unsigned char)key[keylen - 1]); )
 			keylen--;
 
 		/* temporary NUL terminate */
@@ -325,23 +338,23 @@ writepage(FILE *fp, const char *filename, struct variable *c, char *s)
 
 		if (!v) {
 			fprintf(stderr, "%s:%zu: error: undefined variable: '%.*s'\n",
-			        filename, line + 1, (int)keylen, key);
+			        file, line + 1, (int)keylen, key);
 			exit(1);
 		}
 
 		switch (op) {
-		case '%':
-			if (!v->value[0])
-				break;
-			fpin = efopen(v->value, "rb");
-			catfile(fpin, v->value, fp, filename);
-			fclose(fpin);
+		case '#':
+			fputs(v->value, fp);
 			break;
 		case '$':
 			xmlencode(v->value, fp);
 			break;
-		case '#':
-			fputs(v->value, fp);
+		case '%':
+			if (!v->value[0])
+				break;
+			fpin = efopen(v->value, "rb");
+			catfile(fpin, v->value, fp, file);
+			fclose(fpin);
 			break;
 		}
 	}
